{  Image Button Component -- by Dan English  4/27/96     }
{  Copyright 1996  Intenseware  (free to public domain)  }

{  This component is actually a descendent from a TPanel                    }
{  and was designed for larger images with more colors than a TBitBtn.      }
{  Notice there are no 'transparent' pixels or color distortions.           }
{  Please report any bugs to 103256,3104@compuserve.com                     }

unit Imgbtn;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls;

type
  {Special Image Class -- used by Image Button only}
   TBImage = class(TImage)
  private
  protected
    procedure Click; override;
    procedure Mousedown(Button: TMouseButton; Shift: TShiftState; X, Y: Integer); override;
    procedure MouseUp(Button: TMouseButton; Shift: TShiftState; X, Y: Integer); override;
  public
  published
  end;

  {Image Button Class}
  TImgBtn = class(TPanel)
  private
    FBImage  : TBImage;
    FBitmap  : TBitmap;
   procedure Resize;
  protected
    procedure CreateParams( var Params: TCreateParams ); override;
    procedure WMSize(var Message: TWMSize); message WM_SIZE;
    function  GetImage      : TBitmap;
    procedure SetImage      ( Value: TBitmap );
    function  GetImgStretch : Boolean;
    procedure SetImgStretch ( Value: Boolean );
    function  GetImgCenter  : Boolean;
    procedure SetImgCenter  ( Value: Boolean );
  public
    constructor Create(AOwner: TComponent); override;
    destructor  Destroy; override;
  published
    property Image: TBitmap        read GetImage        write SetImage;
    property ImgStretch : Boolean  read GetImgStretch   write SetImgStretch;
    property ImgCenter  : Boolean  read GetImgCenter    write SetImgCenter;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Samples', [TImgBtn]);
end;

{Image Button section}
constructor TImgBtn.Create( AOwner: TComponent );
begin
 inherited Create( AOwner );
 {Create the image on the button}
 FBImage := TBImage.Create( Self );
 FBImage.Parent:= Self;
 FBImage.Align:= alNone;
 Resize;
end;

destructor TImgBtn.Destroy;
begin
 FBImage := nil;
 inherited Destroy;
end;

procedure TImgBtn.CreateParams( var Params: TCreateParams );
begin
 inherited CreateParams( Params );
 Params.Style := Params.Style or WS_CLIPCHILDREN;
end;

{Handle windows sizing events}
procedure TImgBtn.WMSize (var Message: TWMSize);
begin
 ReSize;
end;

{make image correct size}
procedure TImgBtn.ReSize;
begin
 FBImage.Left:= 2;
 FBImage.Top:= 2;
 FBImage.Width:= width - 4;
 FBImage.Height:= height - 4;
 FBImage.Repaint;
 FBImage.Visible:= true;
end;

{functions to set properties of image from ImageBtn }
function TImgBtn.GetImage : TBitmap;
begin
result:= FBImage.Picture.Bitmap;
end;

procedure TImgBtn.SetImage( Value: TBitmap );
begin
if FBImage.Picture.Bitmap <> Value then
   FBImage.Picture.Assign(Value);
end;

function  TImgBtn.GetImgStretch : Boolean;
begin
result:= FBImage.Stretch;
end;

procedure TImgBtn.SetImgStretch(Value: Boolean);
begin
if FBImage.Stretch <> Value then begin
   FBImage.Stretch:= Value;
   FBImage.Repaint;
   end;
end;

function  TImgBtn.GetImgCenter : Boolean;
begin
result:= FBImage.Center;
end;

procedure TImgBtn.SetImgCenter(Value: Boolean);
begin
if FBImage.Center <> Value then begin
   FBImage.Center:= Value;
   FBImage.Repaint;
   end;
end;

{ Special image section }
procedure TBImage.Click;
begin
(Parent as TImgBtn).Click;
 inherited Click;
end;

{Make button & image appear 'down'}
procedure TBImage.Mousedown(Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
(parent as TImgBtn).bevelouter:= bvLowered;
if (parent as TImgBtn).bevelinner = bvRaised then
   (parent as TImgBtn).bevelinner:= bvLowered;
(parent as TImgBtn).FBImage.Left:= 3;
(parent as TImgBtn).FBImage.Top:= 3;
(parent as TImgBtn).FBImage.Width:= (parent as TImgBtn).width - 5;
(parent as TImgBtn).FBImage.Height:= (parent as TImgBtn).height - 5;
(parent as TImgBtn).FBImage.Visible:= true;
end;

{Make button & image appear 'up'}
procedure TBImage.MouseUp(Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
(parent as TImgBtn).bevelouter:= bvRaised;
if (parent as TImgBtn).bevelinner = bvLowered then
   (parent as TImgBtn).bevelinner:= bvRaised;
(parent as TImgBtn).FBImage.Left:= 2;
(parent as TImgBtn).FBImage.Top:= 2;
(parent as TImgBtn).FBImage.Width:= (parent as TImgBtn).width - 4;
(parent as TImgBtn).FBImage.Height:= (parent as TImgBtn).height - 4;
(parent as TImgBtn).FBImage.Visible:= true;
end;

end.
